@@ -9,10 +9,9 @@
 
 // Qt
 #include <QList>
-#include <QMutex>
 
 // System
-#include <time.h>
+#include <unistd.h>
 
 // Utils
 #include <utils/d_ptr_implementation.h>
